@@ -109,7 +109,7 @@ class UnfoldedAhb:
                         code=None,
                         qualifier=None,
                         beschreibung=None,
-                        bedinung_ausdruck=ahb_expression or None,
+                        bedingung_ausdruck=ahb_expression or None,
                         bedingung=None,
                     )
                 )
@@ -129,8 +129,8 @@ class UnfoldedAhb:
                         code=value_pool_entry,
                         qualifier="",
                         beschreibung=description,
-                        bedinung_ausdruck=row[pruefi] or None,
-                        bedingung=row["Beschreibung"],
+                        bedingung_ausdruck=row[pruefi] or None,
+                        bedingung=row["Bedingung"],
                     )
                 )
 
@@ -145,8 +145,8 @@ class UnfoldedAhb:
                         code=None,
                         qualifier="",
                         beschreibung=None,
-                        bedinung_ausdruck=row[pruefi] or None,
-                        bedingung=row["Beschreibung"],
+                        bedingung_ausdruck=row[pruefi] or None,
+                        bedingung=row["Bedingung"],
                     )
                 )
                 continue
@@ -165,8 +165,8 @@ class UnfoldedAhb:
                         code=value_pool_entry,
                         qualifier="",
                         beschreibung=description,
-                        bedinung_ausdruck=row[pruefi] or None,
-                        bedingung=row["Beschreibung"],
+                        bedingung_ausdruck=row[pruefi] or None,
+                        bedingung=row["Bedingung"],
                     )
                 )
                 continue
@@ -191,8 +191,8 @@ class UnfoldedAhb:
                         code=value_pool_entry,
                         qualifier="",
                         beschreibung=description,
-                        bedinung_ausdruck=row[pruefi] or None,
-                        bedingung=row["Beschreibung"],
+                        bedingung_ausdruck=row[pruefi] or None,
+                        bedingung=row["Bedingung"],
                     )
                 )
                 continue
@@ -207,15 +207,22 @@ class UnfoldedAhb:
                         code=row["Codes und Qualifier"],
                         qualifier="",
                         beschreibung=row["Beschreibung"],
-                        bedinung_ausdruck=row[pruefi] or None,
+                        bedingung_ausdruck=row[pruefi] or None,
                         bedingung=row["Bedingung"],
                     )
                 )
 
+        metadata = {"name": "" or None, "communication_direction": "" or None}
+        if len(ahb_table.metadata) > 0:
+            metadata["name"] = ahb_table.metadata[0].name or None
+            metadata["communication_direction"] = ahb_table.metadata[0].communication_direction or None
+
         return cls(
             unfolded_ahb_lines=unfolded_ahb_lines,
             meta_data=UnfoldedAhbTableMetaData(
                 pruefidentifikator=pruefi,
+                beschreibung=metadata["name"],
+                kommunikation_von=metadata["communication_direction"],
             ),
         )
 
@@ -306,7 +313,11 @@ class UnfoldedAhb:
         """
         Converts the unfolded AHB to a flat AHB.
         """
-        meta = AhbMetaInformation(pruefidentifikator=self.meta_data.pruefidentifikator)
+        meta = AhbMetaInformation(
+            pruefidentifikator=self.meta_data.pruefidentifikator,
+            description=self.meta_data.beschreibung,
+            direction=self.meta_data.kommunikation_von,
+        )
         lines: list[AhbLine] = []
 
         for unfolded_ahb_line in self.unfolded_ahb_lines:
@@ -318,7 +329,7 @@ class UnfoldedAhb:
                     data_element=unfolded_ahb_line.datenelement,
                     value_pool_entry=unfolded_ahb_line.code,
                     name=unfolded_ahb_line.beschreibung or unfolded_ahb_line.qualifier,
-                    ahb_expression=unfolded_ahb_line.bedinung_ausdruck,
+                    ahb_expression=unfolded_ahb_line.bedingung_ausdruck,
                     section_name=unfolded_ahb_line.segment_name,
                     index=unfolded_ahb_line.index,
                 )
@@ -360,6 +371,10 @@ class UnfoldedAhb:
             self.meta_data.pruefidentifikator,
             flatahb_output_directory_path / f"{self.meta_data.pruefidentifikator}.json",
         )
+        del flat_ahb
+        del dump_data
+        if "existing_flat_ahb" in locals():
+            del existing_flat_ahb
 
     def convert_to_dataframe(self) -> pd.DataFrame:
         """
@@ -374,7 +389,7 @@ class UnfoldedAhb:
                 "Code": unfolded_ahb_line.code,
                 "Qualifier": unfolded_ahb_line.qualifier,
                 "Beschreibung": unfolded_ahb_line.beschreibung,
-                "Bedingungsausdruck": unfolded_ahb_line.bedinung_ausdruck,
+                "Bedingungsausdruck": unfolded_ahb_line.bedingung_ausdruck,
                 "Bedingung": unfolded_ahb_line.bedingung,
             }
             for unfolded_ahb_line in self.unfolded_ahb_lines
@@ -443,3 +458,41 @@ class UnfoldedAhb:
             self.meta_data.pruefidentifikator,
             xlsx_output_directory_path / f"{self.meta_data.pruefidentifikator}.json",
         )
+
+    def collect_condition(self, already_known_conditions: dict) -> None:
+        """
+        Collect conditions of UnfoldedAHB in dict if they are not known yet.
+        """
+        df = self.convert_to_dataframe()
+
+        edifact_format = get_format_of_pruefidentifikator(self.meta_data.pruefidentifikator)
+        if edifact_format is None:
+            logger.warning("'%s' is not a pruefidentifikator", self.meta_data.pruefidentifikator)
+            return
+        if already_known_conditions.get(edifact_format) is None:
+            already_known_conditions[edifact_format] = {}
+        # check if there are conditions:
+        there_are_conditions = (df["Bedingung"] != "").any()
+        if there_are_conditions:
+            for conditions_text in df["Bedingung"][df["Bedingung"] != ""]:
+                # Split the input into parts enclosed in square brackets and other parts
+                matches = re.findall(
+                    r"\[(\d+)](.*?)(?=\[\d+]|$)",
+                    conditions_text,
+                    re.DOTALL,
+                )
+                for match in matches:
+                    # make text prettier:
+                    text = match[1].strip()
+                    text = re.sub(r"\s+", " ", text)
+                    # check whether condition was already collected:
+                    condition_key_not_collected_yet = already_known_conditions[edifact_format].get(match[0]) is None
+                    if not condition_key_not_collected_yet:
+                        key_exits_but_shorter_text = len(text) > len(
+                            already_known_conditions[edifact_format].get(match[0])
+                        )
+                    if condition_key_not_collected_yet or key_exits_but_shorter_text:
+                        already_known_conditions[edifact_format][match[0]] = text
+
+        logger.info("The conditions for %s were collected", self.meta_data.pruefidentifikator)
+        del df
